@@ -3,9 +3,9 @@
 
 __title__ = 'python_filmaffinity'
 __summary__ = 'Python wrapper for FilmAffinity'
-__url__ = 'https://github.com/sergiormb/python_filmaffinityy'
+__url__ = 'https://github.com/sergiormb/python_filmaffinity'
 
-__version__ = '0.0.16'
+__version__ = '0.0.17'
 
 __install_requires__ = [
     'requests>=2.24.0',
